Membuat dan mengonfigurasi profil aplikasi
Profil aplikasi Bigtable (profil aplikasi) memungkinkan Anda menentukan kebijakan perutean, opsi komputasi, dan setelan isolasi workload untuk permintaan klien yang masuk. Anda dapat mengarahkan traffic di seluruh node cluster yang disediakan, menjalankan pembacaan throughput tinggi yang terisolasi menggunakan komputasi serverless Data Boost, atau merutekan pembacaan titik ke tingkat dalam memori (Pratinjau) pada instance Enterprise Plus.
Sebelum memulai
Sebelum membuat atau mengonfigurasi profil aplikasi, baca dokumentasi berikut:
- Baca Ringkasan profil aplikasi untuk mempelajari cara kerja profil aplikasi dan perbedaan antara profil aplikasi standar untuk komputasi standar dan profil aplikasi Data Boost untuk tugas baca serverless dengan throughput tinggi. Untuk mengetahui informasi selengkapnya tentang perbedaan Data Boost dengan komputasi yang menggunakan node cluster yang disediakan, lihat Ringkasan Bigtable Data Boost.
- Jika Anda menggunakan profil aplikasi standar untuk mengonfigurasi replikasi, baca Ringkasan replikasi dan Contoh konfigurasi replikasi untuk memutuskan setelan yang terbaik untuk kasus penggunaan Anda.
- Jika Anda menggunakan profil aplikasi tingkat dalam memori, baca Ringkasan tingkat dalam memori.
Peran yang diperlukan
Untuk mendapatkan izin yang
diperlukan untuk membuat, mengonfigurasi, atau menghapus profil aplikasi,
minta administrator untuk memberi Anda
peran IAM Bigtable administrator (roles/bigtable.admin) pada instance.
Untuk mengetahui informasi selengkapnya tentang cara memberikan peran, lihat Mengelola akses ke project, folder, dan organisasi.
Anda mungkin juga bisa mendapatkan izin yang diperlukan melalui peran khusus atau peran bawaan lainnya.
Membuat profil aplikasi
Anda dapat membuat banyak profil aplikasi kustom yang berbeda untuk setiap instance. Gunakan profil aplikasi kustom untuk mengontrol cara setiap aplikasi, atau setiap fungsi yang berbeda dalam aplikasi, berinteraksi dengan instance. Misalnya, Anda dapat menggunakan satu profil aplikasi untuk aplikasi batch guna mengisolasi traffic-nya ke satu cluster, dan Anda dapat menggunakan profil aplikasi yang berbeda untuk memberikan ketersediaan tinggi bagi aplikasi lain.
Membuat profil aplikasi standar
Untuk membuat profil aplikasi standar, ikuti langkah-langkah berikut:
Konsol
Di konsol Google Cloud , buka daftar instance Bigtable.
Klik instance tempat Anda ingin membuat profil aplikasi.
Di panel kiri, klik Application profiles.
Klik Create application profile.
Pilih Standard.
Klik Berikutnya.
Masukkan ID profil aplikasi.
ID profil aplikasi adalah ID permanen untuk profil aplikasi. Aplikasi Anda memberikan ID ini saat terhubung ke Bigtable.
Masukkan deskripsi profil aplikasi.
Di bagian Pemilihan rute cluster, pilih pemilihan rute cluster tunggal atau pemilihan rute multi-cluster. Pelajari lebih lanjut.
Jika Anda memilih Single-cluster:
Dalam daftar Cluster, pilih cluster yang akan menerima permintaan.
Jika Anda perlu mengaktifkan transaksi satu baris, centang kotak Allow single-row transactions.
Jika Anda memilih Multi-cluster:
- Dalam daftar Cluster group, untuk merutekan permintaan ke cluster mana pun dalam instance, pilih Any cluster.
- Untuk membatasi perutean permintaan hanya ke beberapa cluster dalam instance (perutean grup cluster), pilih setiap cluster yang ingin Anda sertakan dalam grup perutean, lalu klik OK.
- Untuk merutekan permintaan baca dan tulis satu baris ke cluster tertentu berdasarkan row key permintaan, pilih Enable row affinity.
Di bagian Select a routing priority, tetapkan prioritas pemilihan rute ke permintaan Anda dengan memilih salah satu opsi berikut:
- Tinggi: gunakan untuk permintaan yang sensitif terhadap latensi
- Sedang: digunakan untuk permintaan tujuan umum
- Rendah: digunakan untuk tugas latar belakang atau operasi yang tidak terlalu mendesak
Untuk membuat profil aplikasi, klik Create.
Perbarui kode aplikasi Anda untuk terhubung ke Bigtable agar menggunakan profil aplikasi baru.
gcloud
Jika Anda tidak mengetahui ID instance, gunakan perintah
bigtable instances listuntuk melihat daftar instance project Anda:gcloud bigtable instances listGunakan perintah
bigtable app-profiles createuntuk membuat profil aplikasi:gcloud bigtable app-profiles create APP_PROFILE_ID \ --instance=INSTANCE_ID \ [--description=DESCRIPTION] \ [--force] \ [--route-any] \ [--restrict-to=CLUSTER_ID_1, CLUSTER_ID_2...] \ [--route-to=CLUSTER_ID] \ [--transactional-writes] \ [--priority=PRIORITY] \ [--row-affinity]Berikan hal berikut:
APP_PROFILE_ID: ID permanen untuk profil aplikasi.INSTANCE_ID: ID permanen untuk instance
Perintah ini menerima flag opsional berikut:
--description=DESCRIPTION: Deskripsi mendetail tentang profil aplikasi.--force: Abaikan peringatan tentang potensi masalah dan konflik dengan profil aplikasi lain.--route-any: Aktifkan perutean multi-cluster untuk merutekan permintaan ke cluster yang tersedia.Anda tidak dapat menggabungkan flag ini dengan flag
--route-toatau--transactional-writes.--restrict-to=CLUSTER_ID_1, CLUSTER_ID_2...: Daftar cluster yang menjadi tujuan perutean permintaan. Gunakan opsi ini jika Anda ingin merutekan permintaan hanya ke beberapa cluster dalam instance.Anda tidak dapat menggabungkan flag ini dengan flag
--route-toatau--transactional-writes.--route-to=CLUSTER_ID: ID cluster yang menjadi tujuan perutean semua permintaan. Flag ini mengaktifkan perutean cluster tunggal.Anda tidak dapat menggabungkan flag ini dengan flag
--route-any.--transactional-writes: Aktifkan transaksi satu baris di profil aplikasi.Anda tidak dapat menggabungkan flag ini dengan flag
--route-anyatau--restrict-to.--priority=PRIORITY: Tingkat prioritas yang harus digunakan profil aplikasi. Nilai yang diterima adalahPRIORITY_HIGH,PRIORITY_MEDIUM, atauPRIORITY_LOW.--row-affinity: Aktifkan pemilihan rute afinitas baris di profil aplikasi.Anda tidak dapat menggabungkan flag ini dengan flag
--route-toatau--transactional-writes.
Perbarui kode aplikasi Anda untuk terhubung ke Bigtable agar menggunakan profil aplikasi baru.
Membuat profil aplikasi tingkat dalam memori
Untuk membuat profil aplikasi di cluster dengan tingkat dalam memori yang diaktifkan, ikuti langkah-langkah berikut:
Konsol
Di konsol Google Cloud , buka daftar instance Bigtable.
Klik instance tempat Anda ingin membuat profil aplikasi.
Di panel kiri, klik Application profiles.
Klik Create application profile.
Pilih In-memory tier.
Klik Berikutnya.
Masukkan ID profil aplikasi.
ID profil aplikasi adalah ID permanen untuk profil aplikasi. Aplikasi Anda memberikan ID ini saat terhubung ke Bigtable.
Masukkan deskripsi profil aplikasi.
Di bagian Cluster routing, pilih cluster dengan paket dalam memori yang diaktifkan.
Cluster tingkat dalam memori harus menggunakan pemilihan rute cluster tunggal.
Jika Anda perlu mengaktifkan transaksi satu baris, pilih Allow single-row transactions.
Di bagian Select a routing priority, tetapkan prioritas pemilihan rute ke permintaan Anda dengan memilih salah satu opsi berikut:
- Tinggi: gunakan untuk permintaan yang sensitif terhadap latensi
- Sedang: digunakan untuk permintaan tujuan umum
- Rendah: digunakan untuk tugas latar belakang atau operasi yang tidak terlalu mendesak
Klik Create untuk membuat profil aplikasi.
Perbarui kode aplikasi Anda untuk terhubung ke Bigtable agar menggunakan profil aplikasi baru.
gcloud
Jika Anda tidak mengetahui ID instance, gunakan perintah
bigtable instances listuntuk melihat daftar instance project Anda:gcloud bigtable instances listGunakan perintah
gcloud beta bigtable app-profiles createuntuk membuat profil aplikasi:gcloud beta bigtable app-profiles create APP_PROFILE_ID \ --instance=INSTANCE_ID \ --route-to=CLUSTER_ID \ --use-memory-layer \ [--description=DESCRIPTION] \ [--transactional-writes] \ [--priority=PRIORITY]Berikan hal berikut:
APP_PROFILE_ID: ID permanen untuk profil aplikasi.INSTANCE_ID: ID permanen untuk instance
Perintah ini menerima flag opsional berikut:
--route-to=CLUSTER_ID: ID cluster yang menjadi tujuan perutean semua permintaan. Flag ini mengaktifkan perutean cluster tunggal.--use-memory-layer: Rutekan permintaan dengan profil aplikasi ini ke tingkat dalam memori. Flag ini terbatas untuk edisi Enterprise Plus dan pemilihan rute cluster tunggal.--description=DESCRIPTION: Deskripsi mendetail tentang profil aplikasi.--transactional-writes: Aktifkan transaksi satu baris di profil aplikasi.--priority=PRIORITY: Tingkat prioritas permintaan yang dikirim menggunakan profil aplikasi. Nilai yang diterima adalahPRIORITY_HIGH,PRIORITY_MEDIUM, atauPRIORITY_LOW. Prioritas permintaan tidak memengaruhi permintaan yang memenuhi syarat untuk paket dalam memori.
Perbarui kode aplikasi Anda untuk terhubung ke Bigtable agar menggunakan profil aplikasi baru.
Membuat profil aplikasi Data Boost
Untuk membuat profil aplikasi Data Boost — profil aplikasi yang menggunakan komputasi serverless Data Boost — ikuti langkah-langkah berikut. Untuk memastikan workload Anda kompatibel dengan Data Boost, tinjau batasan.
Konsol
Di konsol Google Cloud , buka daftar instance Bigtable.
Klik instance tempat Anda ingin membuat profil aplikasi.
Di panel kiri, klik Application profiles.
Klik Create application profile.
Pilih Data Boost.
Klik Berikutnya.
Masukkan ID profil aplikasi.
ID profil aplikasi adalah ID permanen untuk profil aplikasi. Aplikasi Anda memberikan ID ini saat terhubung ke Bigtable.
Masukkan deskripsi profil aplikasi.
Di bagian Cluster routing, pilih cluster yang akan menerima permintaan.
Klik Create app profile untuk membuat profil aplikasi.
Perbarui kode aplikasi Anda untuk terhubung ke Bigtable agar menggunakan profil aplikasi baru.
gcloud
Jika Anda tidak mengetahui ID instance, gunakan perintah
bigtable instances listuntuk melihat daftar instance project Anda:gcloud bigtable instances listGunakan perintah
gcloud beta bigtable app-profiles createuntuk membuat profil aplikasi:gcloud bigtable app-profiles create APP_PROFILE_ID \ --instance=INSTANCE_ID \ --data-boost \ --data-boost-compute-billing-owner=HOST_PAYS \ --route-to=CLUSTER_IDBerikan hal berikut:
APP_PROFILE_ID: ID permanen untuk profil aplikasi.INSTANCE_ID: ID permanen untuk instanceCLUSTER_ID: ID cluster yang menjadi tujuan perutean semua permintaan. Flag ini mengaktifkan perutean cluster tunggal.
Menghubungkan dengan profil aplikasi kustom
Setelah membuat profil aplikasi kustom, Anda dapat memperbarui kode agar aplikasi menggunakan profil aplikasi saat terhubung ke Bigtable.
Contoh berikut menunjukkan cara menentukan profil aplikasi saat aplikasi Anda membuat klien Bigtable dan terhubung ke instance. Ganti
[APP_PROFILE_ID] dengan nilai yang sesuai.
C#
var client = BigtableClient.Create(appProfileId: "[APP_PROFILE_ID]");Go
clientConf := bigtable.ClientConfig{AppProfile:"[APP_PROFILE_ID]"}
client, err = bigtable.NewClientWithConfig(ctx, project, instance, clientConf)HBase Java
// If using BigtableOptions directly:
optionsBuilder.setAppProfileId("[APP_PROFILE_ID]");
// If using BigtableOptionsFactory:
configuration.set(BigtableOptionsFactory.APP_PROFILE_ID_KEY, "[APP_PROFILE_ID]");
// If using system properties, set "google.bigtable.app_profile.id" to
// "[APP_PROFILE_ID]"
// If using CloudBigtableIO for Cloud Dataflow:
config.withConfiguration(BigtableOptionsFactory.APP_PROFILE_ID_KEY,
"[APP_PROFILE_ID]");Node.js
const bigtable = new Bigtable({appProfileId: '[APP_PROFILE_ID]'});Python
from google.cloud import bigtable
client = bigtable.Client(project=project_id)
instance = client.instance(instance_id)
table = bigtable.table.Table(table_id, instance, '[APP_PROFILE_ID]')Memperbarui profil aplikasi
Anda dapat melihat profil aplikasi instance dan memperbarui setelannya kapan saja. Bigtable memperingatkan Anda tentang update apa pun yang dapat menyebabkan perubahan perilaku yang tidak terduga.
Untuk mengetahui cara mengupdate profil aplikasi dari standar ke Data Boost atau Data Boost ke standar, lihat Mengonversi profil aplikasi.
Memperbarui profil aplikasi standar
Untuk memperbarui profil aplikasi standar, ikuti langkah-langkah berikut:
Konsol
Di konsol Google Cloud , buka daftar instance Bigtable.
Klik instance dengan profil aplikasi yang ingin Anda perbarui.
Di panel kiri, klik Application profiles.
Klik Edit application profile untuk profil aplikasi yang ingin Anda update.
Perbarui setelan sesuai kebutuhan.
Klik Save atau, untuk keluar tanpa menyimpan, klik Cancel.
gcloud
Jika Anda tidak mengetahui ID instance, gunakan perintah
bigtable instances listuntuk melihat daftar instance project Anda:gcloud bigtable instances listJika Anda tidak mengetahui ID profil aplikasi, gunakan perintah
bigtable app-profiles listuntuk melihat daftar profil aplikasi instance:gcloud bigtable app-profiles list --instance=INSTANCE_IDGanti
INSTANCE_IDdengan ID permanen untuk instance.Opsional: Gunakan perintah
bigtable app-profiles describeuntuk melihat setelan profil aplikasi:gcloud bigtable app-profiles describe APP_PROFILE_ID \ --instance=INSTANCE_IDBerikan hal berikut:
APP_PROFILE_ID: ID permanen untuk profil aplikasi.INSTANCE_ID: ID permanen untuk instance
Gunakan perintah
bigtable app-profiles updateuntuk memperbarui setelan profil aplikasi:gcloud bigtable app-profiles update APP_PROFILE_ID \ --instance=INSTANCE_ID \ [--description=DESCRIPTION] \ [--force] \ [--route-any] \ [--restrict-to=CLUSTER_ID_1, CLUSTER_ID_2...] [--route-to=CLUSTER_ID] \ [--transactional-writes] \ [--row-affinity]Berikan hal berikut:
APP_PROFILE_ID: ID permanen untuk profil aplikasi.INSTANCE_ID: ID permanen untuk instance
Perintah ini menerima flag opsional berikut:
--description=DESCRIPTION: Deskripsi mendetail tentang profil aplikasi.--force: Abaikan peringatan tentang potensi masalah dan konflik dengan profil aplikasi lain.--route-any: Aktifkan perutean multi-cluster untuk merutekan permintaan ke cluster yang tersedia.Anda tidak dapat menggabungkan flag ini dengan flag
--route-toatau--transactional-writes.--restrict-to=CLUSTER_ID_1, CLUSTER_ID_2...: Daftar cluster yang menjadi tujuan perutean permintaan. Gunakan opsi ini jika Anda ingin merutekan permintaan hanya ke beberapa cluster dalam instance.Anda tidak dapat menggabungkan flag ini dengan flag
--route-toatau--transactional-writes.--route-to=CLUSTER_ID: ID cluster yang menjadi tujuan perutean semua permintaan. Flag ini mengaktifkan perutean cluster tunggal.Anda tidak dapat menggabungkan flag ini dengan flag
--route-any.--transactional-writes: Aktifkan transaksi satu baris di profil aplikasi.Anda tidak dapat menggabungkan flag ini dengan flag
--route-any.--priority=PRIORITY: Tingkat prioritas yang digunakan profil aplikasi. Nilai yang diterima adalahPRIORITY_HIGH,PRIORITY_MEDIUM, atauPRIORITY_LOW.
Memperbarui profil aplikasi tingkat dalam memori
Untuk mengupdate profil aplikasi di cluster dengan tingkat dalam memori yang diaktifkan, ikuti langkah-langkah berikut:
Konsol
Di konsol Google Cloud , buka daftar instance Bigtable.
Klik instance dengan profil aplikasi yang ingin Anda perbarui.
Di panel kiri, klik Application profiles.
Klik Edit application profile untuk profil aplikasi yang ingin Anda update.
Perbarui setelan sesuai kebutuhan.
Klik Save atau, untuk keluar tanpa menyimpan, klik Cancel.
gcloud
Jika Anda tidak mengetahui ID instance, gunakan perintah
bigtable instances listuntuk melihat daftar instance project Anda:gcloud bigtable instances listJika Anda tidak mengetahui ID profil aplikasi, gunakan perintah
bigtable app-profiles listuntuk melihat daftar profil aplikasi instance:gcloud bigtable app-profiles list --instance=INSTANCE_IDGanti
INSTANCE_IDdengan ID permanen untuk instance.Opsional: Gunakan perintah
gcloud bigtable app-profiles describeuntuk melihat setelan profil aplikasi:gcloud bigtable app-profiles describe APP_PROFILE_ID \ --instance=INSTANCE_IDBerikan hal berikut:
APP_PROFILE_ID: ID permanen untuk profil aplikasi.INSTANCE_ID: ID permanen untuk instance
Gunakan perintah
gcloud beta bigtable app-profiles updateuntuk memperbarui setelan profil aplikasi:gcloud beta bigtable app-profiles update APP_PROFILE_ID \ --instance=INSTANCE_ID \ --route-to=CLUSTER_ID \ [--description=DESCRIPTION] \ [--transactional-writes] \ [--priority=PRIORITY] \ [--use-memory-layer] \ [--no-use-memory-layer]Berikan hal berikut:
APP_PROFILE_ID: ID permanen untuk profil aplikasi.INSTANCE_ID: ID permanen untuk instance
Perintah ini menerima flag opsional berikut:
--description=DESCRIPTION: Deskripsi mendetail tentang profil aplikasi.--route-to=CLUSTER_ID: ID cluster yang menjadi tujuan perutean semua permintaan. Flag ini mengaktifkan perutean cluster tunggal.--transactional-writes: Aktifkan transaksi satu baris di profil aplikasi.--priority=PRIORITY: Tingkat prioritas yang digunakan profil aplikasi. Nilai yang diterima adalahPRIORITY_HIGH,PRIORITY_MEDIUM, atauPRIORITY_LOW.--use-memory-layer: Rutekan permintaan dengan profil aplikasi ini ke tingkat dalam memori. Gunakan--no-use-memory-layeruntuk menonaktifkan pemilihan rute tingkat dalam memori untuk profil aplikasi ini. Flag ini terbatas untuk edisi Enterprise Plus dan pemilihan rute cluster tunggal.
Memperbarui profil aplikasi Data Boost
Untuk memperbarui cluster yang dibaca oleh profil aplikasi Data Boost, ikuti langkah-langkah berikut:
Konsol
Di konsol Google Cloud , buka daftar instance Bigtable.
Di kolom Application profiles, klik profil aplikasi yang ingin Anda lihat atau perbarui.
Jika tidak melihat profil aplikasi yang ingin diedit, Anda dapat melihat daftar lengkap dengan mengklik nama instance, lalu mengklik Application profiles di panel kiri.
Pilih cluster baru yang akan menjadi tujuan perutean traffic, lalu klik Save.
gcloud
Jika Anda tidak mengetahui ID instance, gunakan perintah
bigtable instances listuntuk melihat daftar instance project Anda:gcloud bigtable instances listJika Anda tidak mengetahui ID profil aplikasi, gunakan perintah
bigtable app-profiles listuntuk melihat daftar profil aplikasi instance:gcloud bigtable app-profiles list --instance=INSTANCE_IDGanti
INSTANCE_IDdengan ID permanen untuk instance.Opsional: Gunakan perintah
gcloud bigtable app-profiles describeuntuk melihat setelan profil aplikasi:gcloud bigtable app-profiles describe APP_PROFILE_ID \ --instance=INSTANCE_IDBerikan hal berikut:
APP_PROFILE_ID: ID permanen untuk profil aplikasi.INSTANCE_ID: ID permanen untuk instance
Gunakan perintah
gcloud beta bigtable app-profiles updateuntuk memperbarui setelan profil aplikasi:gcloud beta bigtable app-profiles update APP_PROFILE_ID \ --instance=INSTANCE_ID \ --route-to=CLUSTER_IDBerikan hal berikut:
APP_PROFILE_ID: ID permanen untuk profil aplikasi.INSTANCE_ID: ID permanen untuk instanceCLUSTER_ID: ID cluster baru yang akan dibaca
Mengonversi profil aplikasi
Anda dapat mengonversi profil aplikasi standar menjadi profil aplikasi Data Boost, atau mengonversi profil aplikasi Data Boost menjadi profil aplikasi standar. Sebelum Anda mengonversi profil aplikasi, tinjau panduan di Perubahan profil aplikasi.
Mengonversi dari standar ke Data Boost
Sebelum Anda mengupdate profil aplikasi dari standar (node yang disediakan untuk komputasi) ke komputasi serverless Data Boost, periksa metrik kelayakan Data Boost. Anda juga harus mengetahui batasan Data Boost.
Konsol
Di konsol Google Cloud , buka daftar instance Bigtable.
Di kolom Application profiles, klik profil aplikasi yang ingin Anda perbarui.
Jika tidak melihat profil aplikasi yang ingin diedit, Anda dapat melihat daftar lengkap dengan mengklik nama instance, lalu mengklik Application profiles di panel kiri.
Pilih Data Boost.
Pilih cluster yang akan menjadi tujuan perutean permintaan.
Klik Simpan.
gcloud
Jika Anda tidak mengetahui ID instance, gunakan perintah
bigtable instances listuntuk melihat daftar instance project Anda:gcloud bigtable instances listJika Anda tidak mengetahui ID profil aplikasi, gunakan perintah
bigtable app-profiles listuntuk melihat daftar profil aplikasi instance:gcloud bigtable app-profiles list --instance=INSTANCE_IDGanti
INSTANCE_IDdengan ID permanen untuk instance.Opsional: Gunakan perintah
bigtable app-profiles describeuntuk melihat setelan profil aplikasi:gcloud bigtable app-profiles describe APP_PROFILE_ID \ --instance=INSTANCE_IDBerikan hal berikut:
APP_PROFILE_ID: ID permanen untuk profil aplikasi.INSTANCE_ID: ID permanen untuk instance
Gunakan perintah
gcloud beta bigtable app-profiles updateuntuk mengonversi profil aplikasi dari standar ke Data Boost:gcloud bigtable app-profiles update APP_PROFILE_ID \ --instance=INSTANCE_ID \ --data-boost \ --data-boost-compute-billing-owner=HOST_PAYS \ --route-to=CLUSTER_IDBerikan hal berikut:
APP_PROFILE_ID: ID permanen untuk profil aplikasi.INSTANCE_ID: ID permanen untuk instanceCLUSTER_ID: ID cluster yang menjadi tujuan perutean semua permintaan. Flag ini mengaktifkan perutean cluster tunggal.
Mengonversi dari Data Boost ke standar
Untuk mengubah profil aplikasi dari menggunakan Data Boost (komputasi serverless) menjadi standar (node yang disediakan untuk komputasi), ikuti langkah-langkah berikut:
Konsol
Di konsol Google Cloud , buka daftar instance Bigtable.
Di kolom Application profiles, klik profil aplikasi yang ingin Anda perbarui.
Jika tidak melihat profil aplikasi yang ingin diedit, Anda dapat melihat daftar lengkap dengan mengklik nama instance, lalu mengklik Application profiles di panel kiri.
Pilih Standard.
Klik Berikutnya.
Opsional: Edit deskripsi profil aplikasi.
Di bagian Pemilihan rute cluster, pilih pemilihan rute cluster tunggal atau pemilihan rute multi-cluster. Pelajari lebih lanjut.
Jika Anda memilih Single-cluster:
Dalam daftar Cluster, pilih cluster yang akan menerima permintaan.
Jika Anda perlu mengaktifkan transaksi satu baris, centang kotak Allow single-row transactions.
Jika Anda memilih Multi-cluster:
- Dalam daftar Cluster group, untuk merutekan permintaan ke cluster mana pun dalam instance, pilih Any cluster.
- Untuk membatasi perutean permintaan hanya ke beberapa cluster dalam instance (perutean grup cluster), pilih setiap cluster yang ingin Anda sertakan dalam grup perutean, lalu klik OK.
- Untuk merutekan permintaan baca dan tulis satu baris ke cluster tertentu berdasarkan row key permintaan, pilih Enable row affinity.
Di bagian Select a routing priority, tetapkan prioritas pemilihan rute ke permintaan Anda dengan memilih salah satu opsi berikut:
- Tinggi: gunakan untuk permintaan yang sensitif terhadap latensi
- Sedang: digunakan untuk permintaan tujuan umum
- Rendah: digunakan untuk tugas latar belakang atau operasi yang tidak terlalu mendesak
Klik Simpan.
gcloud
Jika Anda tidak mengetahui ID instance, gunakan perintah
bigtable instances listuntuk melihat daftar instance project Anda:gcloud bigtable instances listJika Anda tidak mengetahui ID profil aplikasi, gunakan perintah
bigtable app-profiles listuntuk melihat daftar profil aplikasi instance:gcloud bigtable app-profiles list --instance=INSTANCE_IDGanti
INSTANCE_IDdengan ID permanen untuk instance.Opsional: Gunakan perintah
bigtable app-profiles describeuntuk melihat setelan profil aplikasi:gcloud bigtable app-profiles describe APP_PROFILE_ID \ --instance=INSTANCE_IDGunakan perintah
gcloud beta bigtable app-profiles updateuntuk mengonversi profil aplikasi:gcloud bigtable app-profiles update APP_PROFILE_ID \ --instance=INSTANCE_ID \ --standard \ [--route-any] \ [--restrict-to=CLUSTER_ID_1, CLUSTER_ID_2...] [--route-to=CLUSTER_ID] \ [--transactional-writes]
Berikan hal berikut:
APP_PROFILE_ID: ID permanen untuk profil aplikasi.INSTANCE_ID: ID permanen untuk instance
Perintah ini menerima flag opsional berikut:
--route-any: Aktifkan perutean multi-cluster untuk merutekan permintaan ke cluster yang tersedia.Anda tidak dapat menggabungkan flag ini dengan flag
--route-toatau--transactional-writes.--restrict-to=CLUSTER_ID_1, CLUSTER_ID_2...: Daftar cluster yang menjadi tujuan perutean permintaan. Gunakan opsi ini jika Anda ingin merutekan permintaan hanya ke beberapa cluster dalam instance.Anda tidak dapat menggabungkan flag ini dengan flag
--route-toatau--transactional-writes.--route-to=CLUSTER_ID: ID cluster yang menjadi tujuan perutean semua permintaan. Flag ini mengaktifkan perutean cluster tunggal.Anda tidak dapat menggabungkan flag ini dengan flag
--route-any.--transactional-writes: Aktifkan transaksi satu baris di profil aplikasi.Anda tidak dapat menggabungkan flag ini dengan flag
--route-anyatau--restrict-to.
Menghapus profil aplikasi
Anda dapat menghapus profil aplikasi kustom instance, tetapi tidak dapat menghapus profil aplikasi default.
Untuk menghapus profil aplikasi kustom:
Konsol
Di konsol Google Cloud , buka daftar instance Bigtable.
Klik instance yang berisi profil aplikasi yang ingin Anda hapus.
Di panel kiri, klik Application profiles.
Buka menu tindakan lainnya , lalu klik Delete application profile. Dialog konfirmasi akan muncul.
Ikuti petunjuk dalam dialog konfirmasi, lalu klik Hapus.
gcloud
Jika Anda tidak mengetahui ID instance, gunakan perintah
bigtable instances listuntuk melihat daftar instance project Anda:gcloud bigtable instances listJika Anda tidak mengetahui ID profil aplikasi, gunakan perintah
bigtable app-profiles listuntuk melihat daftar profil aplikasi instance:gcloud bigtable app-profiles list --instance=INSTANCE_IDGanti
INSTANCE_IDdengan ID permanen untuk instance.Gunakan perintah
bigtable app-profiles deleteuntuk menghapus profil aplikasi:gcloud bigtable app-profiles delete APP_PROFILE_ID \ --instance=INSTANCE_ID \ [--force]Berikan hal berikut:
APP_PROFILE_ID: ID permanen untuk profil aplikasi.INSTANCE_ID: ID permanen untuk instance
Perintah ini menerima flag opsional berikut:
--force: Abaikan peringatan tentang potensi masalah dan konflik dengan profil aplikasi lain.